@@ -1,15 +1,11 @@
 /*
-** Copyright 2000 Double Precision, Inc.
+** Copyright 1999-2007 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
 /*
-** $Id: cgirelscriptptr.c,v 1.3 2001/03/23 03:18:09 mrsam Exp $
+** $Id: cgirelscriptptr.c,v 1.4 2007/02/24 19:02:59 mrsam Exp $
 */
-#if	HAVE_CONFIG_H
-#include	"config.h"
-#endif
-
 #include	"cgi.h"
 
 #if	HAVE_UNISTD_H
