@@ -5,13 +5,14 @@
 ** See COPYING for distribution information.
 */
 
-static const char cmlmarchive_h_rcsid[]="$Id: cmlmarchive.h,v 1.2 2000/09/16 21:37:20 mrsam Exp $";
+static const char cmlmarchive_h_rcsid[]="$Id: cmlmarchive.h,v 1.3 2007/03/01 04:32:03 mrsam Exp $";
 
 #include	"config.h"
-#include	"afx/afx.h"
 #include	"cmlm.h"
 #include	"mydirent.h"
 
+#include	<string>
+
 /////////////////////////////////////////////////////////////////////////////
 //
 // Message archive.  The Archive class is used to put or get messages from
@@ -30,7 +31,7 @@ public:
 	int get_seq_no(unsigned long &);	// Return next seq no of msg
 	int save_seq_no();		// Save the sequence number
 
-static	CString filename(unsigned long);
+	static	std::string filename(unsigned long);
 } ;
 
 
@@ -41,7 +42,7 @@ public:
 	ArchiveList();
 	~ArchiveList();
 	int	Next(unsigned long &);
-	CString	Next();
+	std::string	Next();
 } ;
 
 #endif
