@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2005 Double Precision, Inc.
+** Copyright 1998 - 2007 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -41,7 +41,7 @@
 #include	<courierauth.h>
 #include	<courierauthsasl.h>
 
-static const char rcsid[]="$Id: courieresmtpd.c,v 1.52 2006/07/07 23:17:18 mrsam Exp $";
+static const char rcsid[]="$Id: courieresmtpd.c,v 1.53 2007/01/06 02:12:56 mrsam Exp $";
 
 static char helobuf[256];
 static char authuserbuf[256];
@@ -1050,7 +1050,7 @@ int	authenticated=0;
 	signal(SIGPIPE, SIG_IGN);
 	/* Some house keeping, while waiting for a reply */
 
-	if (rw_init("esmtp"))	return (1);
+	if (rw_init_courier("esmtp"))	return (1);
 
 	clog_msg_start_info();
 	clog_msg_str("started,ip=[");
