@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2006 Double Precision, Inc.
+** Copyright 1998 - 2007 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -141,7 +141,7 @@ unsigned long mypid=(unsigned long)getpid();
 
 	signal(SIGPIPE, SIG_IGN);
 	srand(time(NULL));
-	rw_init("esmtp");
+	rw_init_courier("esmtp");
 	rewrite_func=rw_search_transport("esmtp")->rw_ptr->rewrite;
 
 	if (chdir(courierdir()))
@@ -237,6 +237,7 @@ unsigned long mypid=(unsigned long)getpid();
 
 static RFC1035_ADDR sockfdaddr;
 static char *sockfdaddrname=0;
+static char *auth_key=0;
 static struct mybuf sockbuf;
 static char writebuf[BUFSIZ];
 static char *writebufptr;
@@ -258,7 +259,7 @@ static void connect_error(struct moduledel *, struct ctlfile *);
 
 static int hello(struct moduledel *, struct ctlfile *);
 static int starttls(struct moduledel *, struct ctlfile *, const char *);
-static int authclient(struct moduledel *, struct ctlfile *);
+static int authclient(struct moduledel *, struct ctlfile *, const char *);
 
 static int rset(struct moduledel *, struct ctlfile *);
 static int smtpreply(const char *, struct moduledel *, struct ctlfile *, int);
@@ -418,14 +419,22 @@ static void sendesmtp(struct moduledel *del, struct ctlfile *ctf)
 
 	if (sockfd < 0)	/* First time, connect to a server */
 	{
-	struct rfc1035_mxlist *mxlist, *p, *q;
-	int static_route= smtproute != NULL;
+		struct rfc1035_mxlist *mxlist, *p, *q;
+		int static_route= smtproute != NULL;
 
 		errno=0;	/* Detect network failures */
 
+		if (auth_key)
+			free(auth_key);
+
+		auth_key=strdup(smtproute ? smtproute:host);
+
+		if (!auth_key)
+			clog_msg_errno();
+
 		rfc1035_init_resolv(&rfc1035_default_resolver);
 		switch (rfc1035_mxlist_create(&rfc1035_default_resolver,
-			smtproute ? smtproute:host, &mxlist))	{
+			auth_key, &mxlist))	{
 		case RFC1035_MX_OK:
 			break;
 		case RFC1035_MX_HARDERR:
@@ -543,7 +552,7 @@ static void sendesmtp(struct moduledel *del, struct ctlfile *ctf)
 						sox_close(sockfd);
 						return;
 					}
-					if (authclient(del, ctf))
+					if (authclient(del, ctf, auth_key))
 					{
 						sox_close(sockfd);
 						return;
@@ -2668,7 +2677,8 @@ struct esmtpauthinfo {
 	int error_sent;
 	} ;
 
-static int authclient(struct moduledel *del, struct ctlfile *ctf)
+static int authclient(struct moduledel *del, struct ctlfile *ctf,
+		      const char *auth_key)
 {
 FILE	*configfile;
 char	uidpwbuf[256];
@@ -2697,13 +2707,13 @@ int	rc;
 		}
 		q=strtok(uidpwbuf, " \t\r\n");
 
-		if (!sockfdaddrname)	continue;
+		if (!sockfdaddrname || !q)	continue;
 
 #if	HAVE_STRCASECMP
-		if (strcasecmp(q, sockfdaddrname) == 0)
+		if (strcasecmp(q, auth_key) == 0)
 			break;
 #else
-		if (stricmp(q, sockfdaddrname) == 0)
+		if (stricmp(q, auth_key) == 0)
 			break;
 #endif
 	}
