@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2005 Double Precision, Inc.
+** Copyright 1998 - 2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -54,7 +54,7 @@
 #include	"liblock/liblock.h"
 #include	"liblock/mail.h"
 
-static const char rcsid[]="$Id: deliver.c,v 1.23 2005/02/04 02:44:59 mrsam Exp $";
+static const char rcsid[]="$Id: deliver.c,v 1.24 2006/05/28 15:29:52 mrsam Exp $";
 
 extern char *local_dotcourier(const char *, const char *, const char **);
 extern char *local_extension();
@@ -413,7 +413,8 @@ static int mbox_fd;
 static RETSIGTYPE truncmbox(int signum)
 {
 #if	HAVE_FTRUNCATE
-	ftruncate(mbox_fd, mbox_size);
+	if (ftruncate(mbox_fd, mbox_size) < 0)
+		; /* ignore */
 #else
 	/* Better than nothing */
 	write(mbox_fd, "\n", 1);
@@ -521,7 +522,8 @@ struct maildir_tmpcreate_info createInfo;
 			)
 		{
 #if	HAVE_FTRUNCATE
-			ftruncate(mbox_fd, mbox_size);
+			if (ftruncate(mbox_fd, mbox_size) < 0)
+				; /* ignore */
 #endif
 			close(mbox_fd);
 			ll_mail_free(ll);
@@ -754,12 +756,10 @@ const char *shell=getenv("SHELL");
 		** External commands have stdout redirected to stderr,
 		** and stdin set to the message.
 		*/
-		close(1);
-		dup(2);
+		dup2(2, 1);
 		if (fileno(f) != 0)
 		{
-			close(0);
-			dup(fileno(f));
+			dup2(fileno(f), 0);
 			fclose(f);
 		}
 
@@ -767,8 +767,7 @@ const char *shell=getenv("SHELL");
 		{
 		const char *c;
 
-			close(1);
-			dup(pipefd[1]);
+			dup2(pipefd[1], 1);
 			close(pipefd[0]);
 			close(pipefd[1]);
 			if (recursion_level >= 3)
