@@ -1,9 +1,9 @@
 /*
-** Copyright 2001-2003 Double Precision, Inc.  See COPYING for
+** Copyright 2001-2006 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
-static const char rcsid[]="$Id: fork.c,v 1.2 2003/06/02 23:47:15 mrsam Exp $";
+static const char rcsid[]="$Id: fork.c,v 1.3 2006/05/28 15:29:52 mrsam Exp $";
 
 #include	"config.h"
 #include	<stdio.h>
@@ -125,29 +125,25 @@ pid_t libmail_gpg_fork(int *libmail_gpg_stdin, int *libmail_gpg_stdout,
 
 	if (libmail_gpg_stderr)
 	{
-		close(2);
-		dup(pipeerr[1]);
+		dup2(pipeerr[1], 2);
 		close(pipeerr[0]);
 		close(pipeerr[1]);
 	}
 	else if (libmail_gpg_stdout)
 	{
-		close(2);
-		dup(pipeout[1]);
+		dup2(pipeout[1], 2);
 	}
 
 	if (libmail_gpg_stdout)
 	{
-		close(1);
-		dup(pipeout[1]);
+		dup2(pipeout[1], 1);
 		close(pipeout[0]);
 		close(pipeout[1]);
 	}
 
 	if (libmail_gpg_stdin)
 	{
-		close(0);
-		dup(pipein[0]);
+		dup2(pipein[0], 0);
 		close(pipein[0]);
 		close(pipein[1]);
 	}
