@@ -3,7 +3,7 @@
 ** distribution information.
 */
 
-static const char rcsid[]="$Id: pcp.c,v 1.7 2004/04/11 17:35:35 mrsam Exp $";
+static const char rcsid[]="$Id: pcp.c,v 1.8 2007/07/01 19:37:05 mrsam Exp $";
 
 #include "config.h"
 #include <stdio.h>
@@ -1613,7 +1613,7 @@ static void usage()
 			"Options:\n"
 			"   -c           - add/uncancel event that conflicts with an existing event\n"
 			"   -s subject   - specify event subject\n"
-			"   -C charset   - specify your local charset (default " RFC2045CHARSET ")\n"
+			"   -C charset   - specify your local charset (default %s)\n"
 			"   -m           - standard input is already a MIME-formatted message\n"
 			"   -e           - list event ids\n"
 			"\n"
@@ -1631,7 +1631,7 @@ static void usage()
 			"   sconnect [/pathname]\n"
 			"   setacl [MODIFY|CONFLICT|LIST|RETR|NONE]*\n"
 			"   listacl\n"
-			)
+			), RFC2045CHARSET
 		);
 	exit(1);
 }
