@@ -51,7 +51,7 @@
 
 #include	"tlsclient.h"
 
-static const char rcsid[]="$Id: tlsclient.c,v 1.3 2003/01/05 04:01:18 mrsam Exp $";
+static const char rcsid[]="$Id: tlsclient.c,v 1.4 2006/05/28 15:29:52 mrsam Exp $";
 
 
 #define ERRMSG(s) (cinfo->errmsg[0]=0, \
@@ -275,7 +275,8 @@ static int do_couriertls_start(char **args, struct couriertls_info *cinfo)
 
 		if (!fp)
 		{
-			write(statuspipe_fd[1], msg, sizeof(msg)-1);
+			if (write(statuspipe_fd[1], msg, sizeof(msg)-1) < 0)
+				; /* Ignore */
 			exit(0);
 		}
 
