@@ -1,9 +1,9 @@
 /*
-** $Id: autoresponse.c,v 1.18 2004/05/23 14:28:24 mrsam Exp $
+** $Id: autoresponse.c,v 1.20 2006/07/22 02:48:15 mrsam Exp $
 */
 
 /*
-** Copyright 2001-2003 Double Precision, Inc.  See COPYING for
+** Copyright 2001-2006 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
@@ -48,7 +48,8 @@ static int save_autoresponse(const char *p, size_t l, void *vp)
 	FILE *fp=*(FILE **)vp;
 
 	if (fp)
-		fwrite(p, l, 1, fp);
+		if (fwrite(p, l, 1, fp) != 1)
+			; /* ignore */
 	return (0);
 }
 
@@ -62,6 +63,11 @@ static int read_headers(FILE *);
 
 void autoresponse()
 {
+const char	*autoresp_title1=getarg("TITLE1");
+const char	*autoresp_title2=getarg("TITLE2");
+const char	*autoresp_text1=getarg("TEXT1");
+const char	*autoresp_text2=getarg("TEXT2");
+
 	if ( *cgi("do.newautoresp"))
 	{
 		const char *name=cgi("newname");
@@ -85,15 +91,13 @@ void autoresponse()
 			return;
 		}
 
-		printf("<p align=\"center\">%s</p>\n", name);
+		printf("%s%s%s\n", autoresp_title1, name, autoresp_title2);
 		printf("<input type=\"hidden\" name=\"autoresponse\" value=\"");
 		output_attrencoded(p);
-		printf("\" /><br /><br />\n");
+		printf("\" />\n");
 		free(p);
 
-		printf("<textarea style=\"font-family: courier;\" cols=\"75\" rows=\"10\" "
-		       "name=\"text\" wrap=\"soft\">");
-		printf("</textarea><br />\n");
+		printf("%s%s\n", autoresp_text1, autoresp_text2);
 		printf("%s<input type=\"file\" size=\"20\" name=\"uploadfile\" /><br />",
 		       getarg("UPLOAD"));
 		printf("<input type=\"submit\" name=\"do.autorespcreate\""
@@ -127,7 +131,7 @@ void autoresponse()
 			return;
 		}
 
-		printf("<p align=\"center\">%s</p>\n", s);
+		printf("%s%s%s\n", autoresp_title1, s, autoresp_title2);
 
 		if (fp && read_headers(fp))
 		{
@@ -150,11 +154,10 @@ void autoresponse()
 
 		printf("<input type=\"hidden\" name=\"autoresponse\" value=\"");
 		output_attrencoded(autorespname);
-		printf("\" /><br /><br />\n");
+		printf("\" />\n");
 		free(s);
 
-		printf("<textarea style=\"font-family: courier;\" cols=\"75\" rows=\"10\" "
-		       "name=\"text\" wrap=\"soft\">");
+		printf("%s", autoresp_text1);
 
 		if (pp && *pp)
 			output_attrencoded(pp);
@@ -168,7 +171,7 @@ void autoresponse()
 		rfc2646_free(parser);
 		if (fp)
 			fclose(fp);
-		printf("\n\n</textarea><br />\n");
+		printf("%s\n", autoresp_text2);
 		printf("%s<input type=\"file\" size=\"20\" name=\"uploadfile\" /><br />",
 		       getarg("UPLOAD"));
 		printf("<input type=\"submit\" name=\"do.autorespcreate\""
@@ -472,10 +475,8 @@ static void end_upload(void *vp)
 
 	if (pid1 == 0)
 	{
-		close(0);
-		dup(fileno(uai->fp));
-		close(1);
-		dup(fileno(afp));
+		dup2(fileno(uai->fp), 0);
+		dup2(fileno(afp), 1);
 		fclose(uai->fp);
 		fclose(afp);
 		execv(MAKEMIME, argvec);
