@@ -4,7 +4,7 @@
 */
 
 /*
-** $Id: msg2html.c,v 1.5 2007/05/20 00:04:55 mrsam Exp $
+** $Id: msg2html.c,v 1.6 2007/07/11 01:35:49 mrsam Exp $
 */
 
 #include "msg2html.h"
@@ -1204,7 +1204,7 @@ const char *q=r;
 		if (*r == '&' && (end-r < 5 || strncmp(r, "&amp;", 5)))
 			break;
 	}
-	if (r > q && (r[-1] == ',' || r[-1] == '.'))	--r;
+	if (r > q && (r[-1] == ',' || r[-1] == '.' || r[-1] == ';'))	--r;
 	return (r);
 }
 
