@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2005 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2007 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: newmsg_create.c,v 1.60 2007/05/07 00:31:54 mrsam Exp $
+** $Id: newmsg_create.c,v 1.62 2007/09/02 19:59:38 mrsam Exp $
 */
 #include	"config.h"
 #include	"cgi/cgi.h"
@@ -424,6 +424,9 @@ char *buf;
 		}
 	}
 
+	if (pref_wikifmt)
+		create_draftheader("x-sqwebmail-wikifmt: ", "1", 0, 0);
+
 	if (!keepheader || keepheader == NEWMSG_PCP)
 	{
 	time_t	t;
@@ -617,6 +620,18 @@ char *buf;
 			enomem();
 		}
 
+#if 0
+	{
+		FILE *fp;
+
+		fp=fopen("/tmp/pid", "w");
+
+		fprintf(fp, "%lu\n", (unsigned long)getpid());
+		fclose(fp);
+		sleep(15);
+	}
+#endif
+
 		rc=rfc2646_parse(flowparser, buf, strlen(buf));
 		if (rc == 0)
 			rc=rfc2646_parse(flowparser, "\n", 1);
@@ -837,6 +852,13 @@ char	*s=rfc2047_decode_simple(value);
 	if (rc)	enomem();
 }
 
+static void createsentmsg_recursive(FILE *fp,
+				    struct rfc2045 *rfcp,
+				    int footer,
+				    int has_wikifmt,
+				    int *found_textplain,
+				    int *found_texthtml);
+
 char *newmsg_createsentmsg(const char *draftname, int *isgpgerr, int footer)
 {
 char	*filename=maildir_find(INBOX "." DRAFTS, draftname);
@@ -850,6 +872,7 @@ int	x;
 off_t	transferencodingpos;
 #endif
 const char	*transfer_encoding=NULL;
+int has_wikifmt=0;
 
 	*isgpgerr=0;
  
@@ -888,6 +911,9 @@ const char	*transfer_encoding=NULL;
 
 	while ((header=maildir_readheader(fp, &value, 1)) != 0)
 	{
+		if (strncmp(header, "x-sqwebmail-wikifmt:", 10) == 0)
+			has_wikifmt=1;
+
 		if (strncmp(header, "x-", 2) == 0)	continue;
 		header_uc(header);
 		if (strcasecmp(header, "To") == 0)
@@ -979,68 +1005,12 @@ const char	*transfer_encoding=NULL;
 				 transfer_encoding);
 	else
 	{
-	int	found_textplain=0;
-	struct rfc2045 *p;
+		int	found_textplain=0;
+		int	found_texthtml=0;
 
-		for (p=rfcp->firstpart; p; p=p->next)
-		{
-		const char *content_type;
-		const char *content_transfer_encoding;
-		const char *charset;
-		off_t	end_pos, start_body, dummy;
-
-			rfc2045_mimeinfo(p, &content_type,
-				&content_transfer_encoding, &charset);
-
-			if (strcmp(content_type, "text/plain") == 0 &&
-				!p->isdummy && !found_textplain)
-			{
-				if (charset && *charset)
-				{
-					rfc2045_mimepos(p, &dummy,
-							&end_pos, &start_body,
-							&dummy, &dummy);
-					transfer_encoding =
-					    libmail_encode_autodetect_fppos(fp,
-						charset, start_body, end_pos);
-				}
-				else
-					transfer_encoding = NULL;
-				maildir_writemsgstr(newdraftfd,
-						    "Content-Type: text/plain");
-				if (charset && *charset)
-				{
-					maildir_writemsgstr(newdraftfd,
-							    "; charset=\"");
-					maildir_writemsgstr(newdraftfd,
-							    charset);
-					maildir_writemsgstr(newdraftfd, "\"");
-				}
-				maildir_writemsgstr(newdraftfd,
-						    "; format=flowed");
-				maildir_writemsgstr(newdraftfd, "\n");
-
-				if (transfer_encoding)
-				{
-					maildir_writemsgstr(newdraftfd,
-					    "Content-Transfer-Encoding: ");
-					maildir_writemsgstr(newdraftfd,
-						transfer_encoding);
-					maildir_writemsgstr(newdraftfd, "\n");
-				}
-				maildir_writemsgstr(newdraftfd, "\n");
-
-				sentmsg_reformat(fp, p, footer,
-						 transfer_encoding);
-				found_textplain=1;
-			}
-			else	sentmsg_copy(fp, p);
-			maildir_writemsgstr(newdraftfd, "\n--");
-			maildir_writemsgstr(newdraftfd, rfc2045_boundary(rfcp));
-			if (!p->next)
-				maildir_writemsgstr(newdraftfd, "--");
-			maildir_writemsgstr(newdraftfd, "\n");
-		}
+		createsentmsg_recursive(fp, rfcp, footer,
+					has_wikifmt,
+					&found_textplain, &found_texthtml);
 	}
 	if ( maildir_writemsg_flush(newdraftfd))
 	{
@@ -1160,12 +1130,167 @@ const char	*transfer_encoding=NULL;
 	return (sentname);
 }
 
+static void createsentmsg_recursive(FILE *fp,
+				    struct rfc2045 *rfcp,
+				    int footer,
+				    int has_wikifmt,
+				    int *found_textplain,
+				    int *found_texthtml)
+{
+	struct rfc2045 *p;
+	char buf[BUFSIZ];
+
+	for (p=rfcp->firstpart; p; p=p->next)
+	{
+		const char *content_type;
+		const char *content_transfer_encoding;
+		const char *charset;
+		off_t	end_pos, start_body, dummy;
+
+		rfc2045_mimeinfo(p, &content_type,
+				 &content_transfer_encoding, &charset);
+
+		if (p->firstpart)
+		{
+			off_t start_parent_pos;
+			off_t start_1stchild_pos;
+
+			rfc2045_mimepos(p, &start_parent_pos,
+					&dummy, &dummy,
+					&dummy, &dummy);
+
+			rfc2045_mimepos(p->firstpart, &start_1stchild_pos,
+					&dummy, &dummy,
+					&dummy, &dummy);
+
+			if (fseek(fp, start_parent_pos, SEEK_SET) < 0)
+			{
+				fclose(fp);
+				close(newdraftfd);
+				enomem();
+			}
+
+			while (start_parent_pos < start_1stchild_pos)
+			{
+				int n;
+
+				n=start_1stchild_pos-start_parent_pos >
+					sizeof(buf)-1 ? sizeof(buf)-1:
+					(int)start_1stchild_pos-start_parent_pos;
+
+				n=fread(buf, 1, n, fp);
+
+				if (n <= 0)
+				{
+					fclose(fp);
+					close(newdraftfd);
+					enomem();
+				}
+
+				buf[n]=0;
+				maildir_writemsgstr(newdraftfd, buf);
+				start_parent_pos += n;
+			}
+
+			createsentmsg_recursive(fp, p, footer, has_wikifmt,
+						found_textplain,
+						found_texthtml);
+		}
+		else if (strcmp(content_type, "text/plain") == 0 &&
+			 !p->isdummy && !*found_textplain)
+		{
+			const char *transfer_encoding;
+
+			if (charset && *charset)
+			{
+				rfc2045_mimepos(p, &dummy,
+						&end_pos, &start_body,
+						&dummy, &dummy);
+				transfer_encoding =
+					libmail_encode_autodetect_fppos(fp,
+									charset, start_body, end_pos);
+			}
+			else
+				transfer_encoding = NULL;
+			maildir_writemsgstr(newdraftfd,
+					    "Content-Type: text/plain");
+			if (charset && *charset)
+			{
+				maildir_writemsgstr(newdraftfd,
+						    "; charset=\"");
+				maildir_writemsgstr(newdraftfd,
+						    charset);
+				maildir_writemsgstr(newdraftfd, "\"");
+			}
+			maildir_writemsgstr(newdraftfd,
+					    "; format=flowed");
+			maildir_writemsgstr(newdraftfd, "\n");
+
+			if (transfer_encoding)
+			{
+				maildir_writemsgstr(newdraftfd,
+						    "Content-Transfer-Encoding: ");
+				maildir_writemsgstr(newdraftfd,
+						    transfer_encoding);
+				maildir_writemsgstr(newdraftfd, "\n");
+			}
+			maildir_writemsgstr(newdraftfd, "\n");
+
+			sentmsg_reformat(fp, p, footer,
+					 transfer_encoding);
+			*found_textplain=1;
+		}
+		else
+		{
+			sentmsg_copy(fp, p);
+
+			if (has_wikifmt && footer &&
+			    strcmp(content_type, "text/html") == 0 &&
+			    !*found_texthtml)
+			{
+				*found_texthtml=1;
+				if (footer)
+				{
+					FILE *footerfile=
+						http11_open_langfile(get_templatedir(),
+								     sqwebmail_content_language,
+								     "footer");
+					if (footerfile)
+					{
+						int n;
+
+						maildir_writemsgstr(newdraftfd, "<pre>\n");
+
+						while ((n=fread(buf, 1, sizeof(buf)-1, footerfile)) > 0)
+						{
+							buf[n]=0;
+							maildir_writemsgstr(newdraftfd, buf);
+						}
+						fclose(footerfile);
+						maildir_writemsgstr(newdraftfd, "</pre>\n");
+					}
+
+				}
+			}
+		}
+
+
+
+
+		maildir_writemsgstr(newdraftfd, "\n--");
+		maildir_writemsgstr(newdraftfd, rfc2045_boundary(rfcp));
+		if (!p->next)
+			maildir_writemsgstr(newdraftfd, "--");
+		maildir_writemsgstr(newdraftfd, "\n");
+	}
+}
+
 /* Note - sentmsg_copy is also reused in newmsg_copy_attachments */
 
 static void sentmsg_copy(FILE *f, struct rfc2045 *p)
 {
 off_t start_pos, end_pos, start_body;
-char buf[512];
+char buf[BUFSIZ];
 int n;
 off_t	dummy;
 
