@@ -1,5 +1,5 @@
 /*
-** $Id: pref.h,v 1.11 2001/11/01 01:49:31 mrsam Exp $
+** $Id: pref.h,v 1.12 2005/11/19 21:57:29 mrsam Exp $
 */
 #ifndef	pref_h
 #define	pref_h
@@ -29,6 +29,7 @@ extern int pref_showhtml;
 extern int pref_noflowedtext;
 extern int pref_noarchive;
 extern int pref_startofweek;
+extern int pref_wikifmt;
 
 extern char *pref_from;
 extern char *pref_ldap;
@@ -37,7 +38,7 @@ extern void pref_init();
 extern void pref_signature();
 extern void pref_setfrom(const char *p);
 extern void pref_setldap(const char *p);
-
+extern void pref_update();
 
 extern char *pref_getdefaultgpgkey();
 extern void pref_setdefaultgpgkey(const char *);
