@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: sqwebmail.c,v 1.142 2007/03/05 04:43:24 mrsam Exp $
+** $Id: sqwebmail.c,v 1.143 2007/09/03 15:44:10 mrsam Exp $
 */
 #include	"sqwebmail.h"
 #include	"sqconfig.h"
@@ -177,6 +177,19 @@ size_t get_timeoutsoft()
 	return n;
 }
 
+size_t get_timeouthard()
+{
+	time_t n=TIMEOUTHARD;
+	const char *p;
+
+	p=getenv("SQWEBMAIL_TIMEOUTHARD");
+
+	if (p && *p)
+		n=atoi(p);
+
+	return n;
+}
+
 void fake_exit(int n)
 {
 	maildir_cache_cancel();
@@ -2119,7 +2132,7 @@ static int valid_redirect()
 	timestamp_t=(time_t)timestamp_n;
 	time(&now);
 
-	if (now < timestamp_t || now > timestamp_t + TIMEOUTHARD)
+	if (now < timestamp_t || now > timestamp_t + get_timeouthard())
 		return 0;
 
 	p=redirect_hash(timestamp);
@@ -2189,7 +2202,7 @@ const char	*ip_addr;
 char	*pi;
 char	*pi_malloced;
 int	reset_cookie=0;
-time_t	timeouthard=TIMEOUTHARD;
+time_t	timeouthard=get_timeouthard();
 
 
 #ifdef	GZIP
@@ -2217,10 +2230,7 @@ time_t	timeouthard=TIMEOUTHARD;
 	umask(0077);
 
 	{
-		const char *p=getenv("SQWEBMAIL_TIMEOUTHARD");
-
-		if (p && *p)
-			timeouthard=atoi(p);
+		timeouthard=get_timeouthard();
 	}
 
 	if (maildir_cache_init(timeouthard, CACHEDIR, CACHEOWNER, authvars))
